#include <std_include.hpp>
#include <utils/string.hpp>

#include "game.hpp"

namespace dvars
{
	game::dvar_t* con_inputBoxColor = nullptr;
	game::dvar_t* con_inputHintBoxColor = nullptr;
	game::dvar_t* con_outputBarColor = nullptr;
	game::dvar_t* con_outputSliderColor = nullptr;
	game::dvar_t* con_outputWindowColor = nullptr;
	game::dvar_t* con_inputDvarMatchColor = nullptr;
	game::dvar_t* con_inputDvarValueColor = nullptr;
	game::dvar_t* con_inputDvarInactiveValueColor = nullptr;
	game::dvar_t* con_inputCmdMatchColor = nullptr;

	game::dvar_t* jump_enableFallDamage;

	game::dvar_t* r_fullbright;

	game::dvar_t* cg_legacyCrashHandling;

	game::dvar_t* g_enableElevators = nullptr;

	std::string dvar_get_vector_domain(const int components, const game::dvar_limits& domain)
	{
		if (domain.vector.min == -FLT_MAX)
		{
			if (domain.vector.max == FLT_MAX)
			{
				return utils::string::va("Domain is any %iD vector", components);
			}
			else
			{
				return utils::string::va("Domain is any %iD vector with components %g or smaller", components,
				                         domain.vector.max);
			}
		}
		else if (domain.vector.max == FLT_MAX)
		{
			return utils::string::va("Domain is any %iD vector with components %g or bigger", components,
			                         domain.vector.min);
		}
		else
		{
			return utils::string::va("Domain is any %iD vector with components from %g to %g", components,
			                         domain.vector.min, domain.vector.max);
		}
	}

	std::string dvar_get_domain(const game::dvar_type type, const game::dvar_limits& domain)
	{
		std::string str;

		switch (type)
		{
		case game::dvar_type::boolean:
			return "Domain is 0 or 1"s;

		case game::dvar_type::value:
			if (domain.value.min == -FLT_MAX)
			{
				if (domain.value.max == FLT_MAX)
				{
					return "Domain is any number"s;
				}

				return utils::string::va("Domain is any number %g or smaller", domain.value.max);
			}

			if (domain.value.max == FLT_MAX)
			{
				return utils::string::va("Domain is any number %g or bigger", domain.value.min);
			}

			return utils::string::va("Domain is any number from %g to %g", domain.value.min, domain.value.max);

		case game::dvar_type::vec2:
			return dvar_get_vector_domain(2, domain);

		case game::dvar_type::rgb:
		case game::dvar_type::vec3:
			return dvar_get_vector_domain(3, domain);

		case game::dvar_type::vec4:
			return dvar_get_vector_domain(4, domain);

		case game::dvar_type::integer:
			if (domain.enumeration.stringCount == INT_MIN)
			{
				if (domain.integer.max == INT_MAX)
				{
					return "Domain is any integer"s;
				}

				return utils::string::va("Domain is any integer %i or smaller", domain.integer.max);
			}

			if (domain.integer.max == INT_MAX)
			{
				return utils::string::va("Domain is any integer %i or bigger", domain.integer.min);
			}

			return utils::string::va("Domain is any integer from %i to %i", domain.integer.min, domain.integer.max);

		case game::dvar_type::color:
			return "Domain is any 4-component color, in RGBA format"s;

		case game::dvar_type::enumeration:
			str = "Domain is one of the following:"s;

			for (auto string_index = 0; string_index < domain.enumeration.stringCount; ++string_index)
			{
				str += utils::string::va("\n  %2i: %s", string_index, domain.enumeration.strings[string_index]);
			}

			return str;

		case game::dvar_type::string:
			return "Domain is any text"s;

		default:
			return utils::string::va("unhandled dvar type '%i'", type);
		}
	}

	std::unordered_set<std::string> dvar_list = 
	{
        "aa_ads_damage_dealt",
        "aa_deaths",
        "aa_enemy_damage_taken",
        "aa_enemy_deaths",
        "aa_player_damage_dealt",
        "aa_player_damage_taken",
        "aa_player_kills",
        "aa_time_tracking",
        "aa_zoneaa_main_deer_hunt",
        "ac130_player_num",
        "accessToSubscriberContent",
        "actionSlotsHide",
        "actor_spaceLightingOffset",
        "actor_trace_bound_offset",
        "actorVisibilityCheckAngleDistMax",
        "actorVisibilityCheckAngleDistMin",
        "actorVisibilityMinCheckAngle",
        "ads_dof_debug",
        "ads_dof_farBlur",
        "ads_dof_farEndScale",
        "ads_dof_farStartScale",
        "ads_dof_maxEnemyDist",
        "ads_dof_nearBlur",
        "ads_dof_nearEndScale",
        "ads_dof_nearStartScale",
        "ads_dof_playerForgetEnemyTime",
        "ads_dof_tracedist",
        "agent_jumpGravity",
        "agent_jumpSpeed",
        "agent_jumpWallGravity",
        "agent_jumpWallSpeed",
        "ai_accuracy_attackerCountDecrease",
        "ai_accuracy_attackerCountMax",
        "ai_accuracyDistScale",
        "ai_badPathSpam",
        "ai_busyEventDistBullet",
        "ai_busyEventDistDeath",
        "ai_busyEventDistExplosion",
        "ai_busyEventDistFootstep",
        "ai_busyEventDistFootstepSprint",
        "ai_busyEventDistFootstepWalk",
        "ai_busyEventDistGrenadePing",
        "ai_busyEventDistGunShot",
        "ai_busyEventDistGunShotTeam",
        "ai_busyEventDistNewEnemy",
        "ai_busyEventDistPain",
        "ai_busyEventDistProjImpact",
        "ai_busyEventDistProjPing",
        "ai_busyEventDistSilencedShot",
        "ai_corpseCount",
        "ai_corpseLimit",
        "ai_count",
        "ai_coverScore_coverType",
        "ai_coverScore_dangerousNode",
        "ai_coverScore_distance",
        "ai_coverScore_engagement",
        "ai_coverScore_nodeAngle",
        "ai_coverScore_playerLos",
        "ai_coverScore_priority",
        "ai_coverScore_targetDir",
        "ai_coverScore_visibility",
        "ai_coverSearchInterval",
        "ai_dangerReactGoalRadius",
        "ai_debug_count",
        "ai_debugAccuracy",
        "ai_debugAnimDeltas",
        "ai_debugCorpsePlant",
        "ai_debugCoverEntityNum",
        "ai_debugCoverSelection",
        "ai_debugEngagementDist",
        "ai_debugGrenadeFailSafe",
        "ai_debugGrenadeHintArc",
        "ai_debugGunBlocked",
        "ai_debugMayMove",
        "ai_debugMeleeAttackSpots",
        "ai_debugOverlay",
        "ai_debugPlayerLOS",
        "ai_debugTargets",
        "ai_debugVolume",
        "ai_disableSpawn",
        "ai_dropAkimboChance",
        "ai_eventDistBadPlace",
        "ai_eventDistBullet",
        "ai_eventDistDeath",
        "ai_eventDistExplosion",
        "ai_eventDistFootstep",
        "ai_eventDistFootstepSprint",
        "ai_eventDistFootstepWalk",
        "ai_eventDistGrenadePing",
        "ai_eventDistGunShot",
        "ai_eventDistGunShotTeam",
        "ai_eventDistNewEnemy",
        "ai_eventDistPain",
        "ai_eventDistProjImpact",
        "ai_eventDistProjPing",
        "ai_eventDistSilencedShot",
        "ai_friendlyFireBlockDuration",
        "ai_friendlySuppression",
        "ai_friendlySuppressionDist",
        "ai_frontShieldDamageReduction",
        "ai_maxGrenadeThrowSpeed",
        "ai_moveOrientMode",
        "ai_noDodge",
        "ai_pathMomentum",
        "ai_playerADSTargetTime",
        "ai_playerLOSHalfWidth",
        "ai_playerLOSMinTime",
        "ai_playerLOSRange",
        "ai_ShowCanshootChecks",
        "ai_showDodge",
        "ai_showLikelyEnemyPathNode",
        "ai_showRegion",
        "ai_showSuppression",
        "aim_autoAimRangeScale",
        "aim_automelee_lerp",
        "aim_automelee_range",
        "aim_automelee_range_crouched",
        "aim_automelee_range_prone",
        "aim_automelee_range_standing",
        "aim_automelee_region_height",
        "aim_automelee_region_width",
        "aim_resist_pitch_enabled",
        "aim_resist_view_threshold",
        "aim_resist_yaw_enabled",
        "aim_target_sentient_radius",
        "allow_cod_anywhere",
        "allow_online_squads",
        "allow_secondscreen",
        "allow_secondscreen_ingame_recv",
        "allow_secondscreen_ingame_send",
        "ammoCounterHide",
        "angles",
        "arcademode",
        "arcademode_lives",
        "autobolt_explosions_to_vehicles",
        "autodifficulty_frac",
        "autodifficulty_original_setting",
        "autodifficulty_playerDeathTimer",
        "band_12players",
        "band_18players",
        "band_2players",
        "band_4players",
        "band_8players",
        "bcs_allowsamevoiceresponse",
        "bcs_enable",
        "bcs_filterInform",
        "bcs_filterOrder",
        "bcs_filterReaction",
        "bcs_filterResponse",
        "bcs_filterThreat",
        "bcs_forceEnglish",
        "bg_bulletExplDmgFactor",
        "bg_bulletExplRadius",
        "bg_compassShowEnemies",
        "bg_shieldHitEncodeHeightVM",
        "bg_shieldHitEncodeHeightWorld",
        "bg_shieldHitEncodeWidthVM",
        "bg_shieldHitEncodeWidthWorld",
        "bg_shock_lookControl",
        "bg_shock_lookControl_fadeTime",
        "bg_shock_lookControl_maxpitchspeed",
        "bg_shock_lookControl_maxyawspeed",
        "bg_shock_lookControl_mousesensitivityscale",
        "bg_shock_movement",
        "bg_shock_screenBlurBlendFadeTime",
        "bg_shock_screenBlurBlendTime",
        "bg_shock_screenFlashShotFadeTime",
        "bg_shock_screenFlashWhiteFadeTime",
        "bg_shock_screenType",
        "bg_shock_sound",
        "bg_shock_soundDryLevel",
        "bg_shock_soundEnd",
        "bg_shock_soundEndAbort",
        "bg_shock_soundFadeInTime",
        "bg_shock_soundFadeOutTime",
        "bg_shock_soundLoop",
        "bg_shock_soundLoopEndDelay",
        "bg_shock_soundLoopFadeTime",
        "bg_shock_soundLoopSilent",
        "bg_shock_soundModEndDelay",
        "bg_shock_soundRoomType",
        "bg_shock_soundWetLevel",
        "bg_shock_viewKickFadeTime",
        "bg_shock_viewKickPeriod",
        "bg_shock_viewKickRadius",
        "bg_shock_volume_aircraft",
        "bg_shock_volume_alarm",
        "bg_shock_volume_ambdist1",
        "bg_shock_volume_ambdist2",
        "bg_shock_volume_ambient",
        "bg_shock_volume_announcer",
        "bg_shock_volume_auto",
        "bg_shock_volume_auto2",
        "bg_shock_volume_auto2d",
        "bg_shock_volume_autodog",
        "bg_shock_volume_body",
        "bg_shock_volume_body2d",
        "bg_shock_volume_bulletflesh1",
        "bg_shock_volume_bulletflesh1npc",
        "bg_shock_volume_bulletflesh1npc_npc",
        "bg_shock_volume_bulletflesh2",
        "bg_shock_volume_bulletflesh2npc",
        "bg_shock_volume_bulletflesh2npc_npc",
        "bg_shock_volume_bulletimpact",
        "bg_shock_volume_bulletwhizbyin",
        "bg_shock_volume_bulletwhizbyout",
        "bg_shock_volume_effects1",
        "bg_shock_volume_effects2",
        "bg_shock_volume_effects2d1",
        "bg_shock_volume_effects2d2",
        "bg_shock_volume_effects2dlim",
        "bg_shock_volume_effects3",
        "bg_shock_volume_element",
        "bg_shock_volume_element2d",
        "bg_shock_volume_element_ext",
        "bg_shock_volume_element_int",
        "bg_shock_volume_element_lim",
        "bg_shock_volume_explosion1",
        "bg_shock_volume_explosion2",
        "bg_shock_volume_explosion3",
        "bg_shock_volume_explosion4",
        "bg_shock_volume_explosion5",
        "bg_shock_volume_explosiondist1",
        "bg_shock_volume_explosiondist2",
        "bg_shock_volume_explosiveimpact",
        "bg_shock_volume_foley_dog_mvmt",
        "bg_shock_volume_foley_dog_step",
        "bg_shock_volume_foley_npc_mvmt",
        "bg_shock_volume_foley_npc_step",
        "bg_shock_volume_foley_npc_weap",
        "bg_shock_volume_foley_plr_mvmt",
        "bg_shock_volume_foley_plr_step",
        "bg_shock_volume_foley_plr_step_unres",
        "bg_shock_volume_foley_plr_weap",
        "bg_shock_volume_hurt",
        "bg_shock_volume_item",
        "bg_shock_volume_local",
        "bg_shock_volume_local2",
        "bg_shock_volume_local3",
        "bg_shock_volume_menu",
        "bg_shock_volume_menulim1",
        "bg_shock_volume_menulim2",
        "bg_shock_volume_mission",
        "bg_shock_volume_missionfx",
        "bg_shock_volume_music",
        "bg_shock_volume_music_emitter",
        "bg_shock_volume_musicnopause",
        "bg_shock_volume_nonshock",
        "bg_shock_volume_nonshock2",
        "bg_shock_volume_norestrict",
        "bg_shock_volume_norestrict2d",
        "bg_shock_volume_physics",
        "bg_shock_volume_player1",
        "bg_shock_volume_player2",
        "bg_shock_volume_plr_weap_fire_2d",
        "bg_shock_volume_plr_weap_mech_2d",
        "bg_shock_volume_reload",
        "bg_shock_volume_reload2d",
        "bg_shock_volume_shellshock",
        "bg_shock_volume_vehicle",
        "bg_shock_volume_vehicle2d",
        "bg_shock_volume_vehiclelimited",
        "bg_shock_volume_voice",
        "bg_shock_volume_voice_dog",
        "bg_shock_volume_voice_dog_attack",
        "bg_shock_volume_voice_dog_dist",
        "bg_shock_volume_weapon",
        "bg_shock_volume_weapon2d",
        "bg_shock_volume_weapon_dist",
        "bg_shock_volume_weapon_drone",
        "bg_shock_volume_weapon_mid",
        "bg_viewBobAmplitudeBase",
        "bg_viewBobAmplitudeDucked",
        "bg_viewBobAmplitudeDuckedAds",
        "bg_viewBobAmplitudeProne",
        "bg_viewBobAmplitudeRoll",
        "bg_viewBobAmplitudeSprinting",
        "bg_viewBobAmplitudeStanding",
        "bg_viewBobAmplitudeStandingAds",
        "bg_viewBobMax",
        "bg_viewKickMax",
        "bg_viewKickMin",
        "bg_viewKickRandom",
        "bg_viewKickScale",
        "bg_weaponBobAmplitudeBase",
        "bg_weaponBobAmplitudeDucked",
        "bg_weaponBobAmplitudeProne",
        "bg_weaponBobAmplitudeRoll",
        "bg_weaponBobAmplitudeSprinting",
        "bg_weaponBobAmplitudeStanding",
        "bg_weaponBobLag",
        "bg_weaponBobMax",
        "bullet_penetration_damage",
        "bullet_penetrationActorHitsActors",
        "bullet_penetrationHitsClients",
        "ca_do_mlc",
        "ca_intra_only",
        "cameraShakeRemoteHelo_Angles",
        "cameraShakeRemoteHelo_Freqs",
        "cameraShakeRemoteHelo_SpeedRange",
        "cameraShakeRemoteMissile_Angles",
        "cameraShakeRemoteMissile_Freqs",
        "cameraShakeRemoteMissile_SpeedRange",
        "cg_blood",
        "cg_bloodLimit",
        "cg_bloodLimitMsec",
        "cg_brass",
        "cg_centertime",
        "cg_cinematicCanPause",
        "cg_cinematicFullscreen",
        "cg_ColorBlind_EnemyTeam",
        "cg_ColorBlind_MyTeam",
        "cg_constantSizeHeadIcons",
        "cg_crawlBlendOutTimeFiring",
        "cg_crawlBlendTime",
        "cg_crawlMaxSpeed",
        "cg_crawlMinSpeed",
        "cg_crosshairAlpha",
        "cg_crosshairAlphaMin",
        "cg_crosshairDynamic",
        "cg_crosshairEnemyColor",
        "cg_crosshairVerticalOffset",
        "cg_cullBulletAngle",
        "cg_cullBullets",
        "cg_cursorHints",
        "cg_draw2D",
        "cg_drawBreathHint",
        "cg_drawBuildName",
        "cg_drawCrosshair",
        "cg_drawDamageDirection",
        "cg_drawDamageFlash",
        "cg_drawEffectNum",
        "cg_drawFPS",
        "cg_drawFPSLabels",
        "cg_drawFriendlyFireCrosshair",
        "cg_drawGun",
        "cg_drawHealth",
        "cg_drawHUD",
        "cg_drawMantleHint",
        "cg_drawMaterial",
        "cg_drawpaused",
        "cg_drawPing",
        "cg_drawScriptUsage",
        "cg_drawTechset",
        "cg_drawTurretCrosshair",
        "cg_drawViewpos",
        "cg_enableWaterSurfaceTransitionFx",
        "cg_equipmentSounds",
        "cg_errordecay",
        "cg_foliagesnd_alias",
        "cg_footsteps",
        "cg_footstepsSprint",
        "cg_fov",
        "cg_fov1",
        "cg_fovMin",
        "cg_fovNonVehAdd",
        "cg_fovScale",
        "cg_gameBoldMessageWidth",
        "cg_gameMessageWidth",
        "cg_gun_x",
        "cg_gun_y",
        "cg_gun_z",
        "cg_headIconMinScreenRadius",
        "cg_hintFadeTime",
        "cg_hudDamageIconHeight",
        "cg_hudDamageIconInScope",
        "cg_hudDamageIconOffset",
        "cg_hudDamageIconTime",
        "cg_hudDamageIconWidth",
        "cg_hudGrenadeIconEnabledFlash",
        "cg_hudGrenadeIconHeight",
        "cg_hudGrenadeIconInScope",
        "cg_hudGrenadeIconMaxHeight",
        "cg_hudGrenadeIconMaxRangeFlash",
        "cg_hudGrenadeIconMaxRangeFrag",
        "cg_hudGrenadeIconOffset",
        "cg_hudGrenadeIconWidth",
        "cg_hudGrenadePointerHeight",
        "cg_hudGrenadePointerPivot",
        "cg_hudGrenadePointerPulseFreq",
        "cg_hudGrenadePointerPulseMax",
        "cg_hudGrenadePointerPulseMin",
        "cg_hudGrenadePointerWidth",
        "cg_hudLighting_basic_additiveLumOffset",
        "cg_hudLighting_basic_additiveLumScale",
        "cg_hudLighting_basic_additiveOffset",
        "cg_hudLighting_basic_additiveScale",
        "cg_hudLighting_basic_ambientLumOffset",
        "cg_hudLighting_basic_ambientLumScale",
        "cg_hudLighting_basic_ambientOffset",
        "cg_hudLighting_basic_ambientScale",
        "cg_hudLighting_basic_diffuseLumOffset",
        "cg_hudLighting_basic_diffuseLumScale",
        "cg_hudLighting_basic_diffuseOffset",
        "cg_hudLighting_basic_diffuseScale",
        "cg_hudLighting_basic_specExponent",
        "cg_hudLighting_basic_specLumOffset",
        "cg_hudLighting_basic_specLumScale",
        "cg_hudLighting_basic_specOffset",
        "cg_hudLighting_basic_specScale",
        "cg_hudLighting_blood_additiveLumOffset",
        "cg_hudLighting_blood_additiveLumScale",
        "cg_hudLighting_blood_additiveOffset",
        "cg_hudLighting_blood_additiveScale",
        "cg_hudLighting_blood_ambientLumOffset",
        "cg_hudLighting_blood_ambientLumScale",
        "cg_hudLighting_blood_ambientOffset",
        "cg_hudLighting_blood_ambientScale",
        "cg_hudLighting_blood_diffuseLumOffset",
        "cg_hudLighting_blood_diffuseLumScale",
        "cg_hudLighting_blood_diffuseOffset",
        "cg_hudLighting_blood_diffuseScale",
        "cg_hudLighting_blood_specExponent",
        "cg_hudLighting_blood_specLumOffset",
        "cg_hudLighting_blood_specLumScale",
        "cg_hudLighting_blood_specOffset",
        "cg_hudLighting_blood_specScale",
        "cg_hudLighting_fadeSharpness",
        "cg_hudMapBorderWidth",
        "cg_hudMapFriendlyHeight",
        "cg_hudMapFriendlyWidth",
        "cg_hudMapPlayerHeight",
        "cg_hudMapPlayerWidth",
        "cg_hudMapRadarLineThickness",
        "cg_hudStanceFlash",
        "cg_hudStanceHintPrints",
        "cg_invalidCmdHintBlinkInterval",
        "cg_invalidCmdHintDuration",
        "cg_landingSounds",
        "cg_laserLight",
        "cg_legacyCrashHandling",
        "cg_mapLocationSelectionCursorSpeed",
        "cg_marks_ents_player_only",
        "cg_minCullBulletDist",
        "cg_objectiveListWrapCountStandard",
        "cg_objectiveListWrapCountWidescreen",
        "cg_playerFovScale0",
        "cg_playerFovScale1",
        "cg_scriptIconSize",
        "cg_showmiss",
        "cg_skipDObjFilterIntoCells",
        "cg_small_dev_string_fontscale",
        "cg_sprintMeterDisabledColor",
        "cg_sprintMeterEmptyColor",
        "cg_sprintMeterFullColor",
        "cg_subtitleMinTime",
        "cg_subtitleWidthStandard",
        "cg_subtitleWidthWidescreen",
        "cg_vectorFieldsForceUniform",
        "cg_viewVehicleInfluence",
        "cg_viewZSmoothingMax",
        "cg_viewZSmoothingMin",
        "cg_viewZSmoothingTime",
        "cg_waterSheeting_distortionScaleFactor",
        "cg_waterSheeting_magnitude",
        "cg_waterSheeting_radius",
        "cg_weapHitCullAngle",
        "cg_weapHitCullEnable",
        "cg_weaponCycleDelay",
        "cg_weaponHintsCoD1Style",
        "chaplinCheat",
        "cl_accessibilityAkimboEnabled",
        "cl_anglespeedkey",
        "cl_dirSelConvergenceTime",
        "cl_freelook",
        "cl_lessprint",
        "cl_loadApexDLL",
        "cl_loadHairDLL",
        "cl_loadHBAODLL",
        "cl_loadNVMRDLL",
        "cl_loadNVPSMDLL",
        "cl_loadTXAADLL",
        "cl_maxpackets",
        "cl_modifiedDebugPlacement",
        "cl_mouseAccel",
        "cl_noprint",
        "cl_packetdup",
        "cl_paused",
        "cl_pitchspeed",
        "cl_showmouserate",
        "cl_shownet",
        "cl_showSend",
        "cl_showServerCommands",
        "cl_testAnimWeight",
        "cl_yawspeed",
        "com_animCheck",
        "com_cinematicEndInWhite",
        "com_completionResolveCommand",
        "com_errorResolveCommand",
        "com_filter_output",
        "com_maxfps",
        "com_maxFrameTime",
        "com_playerProfile",
        "com_recommendedSet",
        "com_timescale",
        "commerce_dl_retry_step",
        "commerce_manifest_file_max_retry_time",
        "commerce_manifest_file_retry_step",
        "commerce_max_dl_retry_time",
        "commerce_max_retry_time",
        "commerce_retry_step",
        "compass",
        "compassClampIcons",
        "compassCoords",
        "compassECoordCutoff",
        "compassFriendlyHeight",
        "compassFriendlyWidth",
        "compassHideSansObjectivePointer",
        "compassHideVehicles",
        "compassMaxRange",
        "compassMinRadius",
        "compassMinRange",
        "compassObjectiveArrowHeight",
        "compassObjectiveArrowOffset",
        "compassObjectiveArrowRotateDist",
        "compassObjectiveArrowWidth",
        "compassObjectiveDetailDist",
        "compassObjectiveDrawLines",
        "compassObjectiveHeight",
        "compassObjectiveIconHeight",
        "compassObjectiveIconWidth",
        "compassObjectiveMaxHeight",
        "compassObjectiveMaxRange",
        "compassObjectiveMinAlpha",
        "compassObjectiveMinDistRange",
        "compassObjectiveMinHeight",
        "compassObjectiveNearbyDist",
        "compassObjectiveNumRings",
        "compassObjectiveRingSize",
        "compassObjectiveRingTime",
        "compassObjectiveTextHeight",
        "compassObjectiveTextScale",
        "compassObjectiveWidth",
        "compassPlayerHeight",
        "compassPlayerWidth",
        "compassRadarLineThickness",
        "compassRadarPingFadeTime",
        "compassRotation",
        "compassSize",
        "compassSoundPingFadeTime",
        "compassTickertapeStretch",
        "con_gameMsgWindow0FadeInTime",
        "con_gameMsgWindow0FadeOutTime",
        "con_gameMsgWindow0Filter",
        "con_gameMsgWindow0LineCount",
        "con_gameMsgWindow0MsgTime",
        "con_gameMsgWindow0ScrollTime",
        "con_gameMsgWindow0SplitscreenScale",
        "con_gameMsgWindow1FadeInTime",
        "con_gameMsgWindow1FadeOutTime",
        "con_gameMsgWindow1Filter",
        "con_gameMsgWindow1LineCount",
        "con_gameMsgWindow1MsgTime",
        "con_gameMsgWindow1ScrollTime",
        "con_gameMsgWindow1SplitscreenScale",
        "con_gameMsgWindow2FadeInTime",
        "con_gameMsgWindow2FadeOutTime",
        "con_gameMsgWindow2Filter",
        "con_gameMsgWindow2LineCount",
        "con_gameMsgWindow2MsgTime",
        "con_gameMsgWindow2ScrollTime",
        "con_gameMsgWindow2SplitscreenScale",
        "con_gameMsgWindow3FadeInTime",
        "con_gameMsgWindow3FadeOutTime",
        "con_gameMsgWindow3Filter",
        "con_gameMsgWindow3LineCount",
        "con_gameMsgWindow3MsgTime",
        "con_gameMsgWindow3ScrollTime",
        "con_gameMsgWindow3SplitscreenScale",
        "con_inputBoxColor",
        "con_inputCmdMatchColor",
        "con_inputDvarInactiveValueColor",
        "con_inputDvarMatchColor",
        "con_inputDvarValueColor",
        "con_inputHintBoxColor",
        "con_outputBarColor",
        "con_outputSliderColor",
        "con_outputWindowColor",
        "con_typewriterColorBase",
        "con_typewriterColorGlowCheckpoint",
        "con_typewriterColorGlowCompleted",
        "con_typewriterColorGlowFailed",
        "con_typewriterColorGlowUpdated",
        "con_typewriterDecayDuration",
        "con_typewriterDecayStartTime",
        "con_typewriterPrintSpeed",
        "coop",
        "coop_autoLaunch",
        "coop_backoffScheme",
        "coop_debugPackets",
        "coop_dvarWarnings",
        "coop_fastForwardThreshold",
        "coop_frameDelay",
        "coop_hosttimeout",
        "coop_mapName",
        "coop_matching_type_search",
        "coop_maxFramesClientCanBeBehind",
        "coop_maxFramesPerPacket",
        "coop_maxPacketUserCmds",
        "coop_maxServerLoadWaitTime",
        "coop_minFramesClientCanBeBehind",
        "coop_showing_game_error_popup",
        "coop_start",
        "coop_validateData",
        "coop_waitWarnDelay",
        "coop_waitWarnRate",
        "coopNameFontSize",
        "coopNameFontSizeSplitscreen",
        "counterDownloadInterval",
        "counterUploadInterval",
        "cSplineDebugRender",
        "cSplineDebugRenderCorridor",
        "cSplineDebugRenderData",
        "cSplineDebugRenderSplineId",
        "dc_lobbymerge",
        "debug",
        "debug_audio",
        "debug_bcprint",
        "debug_bcprintdump",
        "debug_bcprintdumptype",
        "debug_bcshowqueue",
        "debug_drones",
        "debug_headroom",
        "dedicated_dhclient",
        "demonwareConsideredConnectedTime",
        "developer",
        "disable_tank_shock_minspec",
        "discard_playerstats_on_suspend",
        "dw_addrHandleTimeout",
        "dw_ignore_hack",
        "dw_leaderboard_write_active",
        "dw_matchmaking_fall_off",
        "dw_presence_active",
        "dw_presence_coop_join_active",
        "dw_presence_get_delay",
        "dw_presence_get_rate",
        "dw_presence_put_delay",
        "dw_presence_put_rate",
        "dw_shared_presence_active",
        "dw_shared_presence_get_delay",
        "dw_shared_presence_get_rate",
        "dw_shared_presence_put_delay",
        "dw_shared_presence_put_rate",
        "dynEnt_active",
        "elite_clan_active",
        "elite_clan_cool_off_time",
        "elite_clan_delay",
        "elite_clan_division_icon_active",
        "elite_clan_get_clan_max_retry_time",
        "elite_clan_get_clan_retry_step",
        "elite_clan_get_members_max_retry_time",
        "elite_clan_get_members_retry_step",
        "elite_clan_get_private_member_profile_max_retry_time",
        "elite_clan_get_private_member_profile_retry_step",
        "elite_clan_get_private_profile_max_retry_time",
        "elite_clan_get_private_profile_retry_step",
        "elite_clan_get_public_profile_max_retry_time",
        "elite_clan_get_public_profile_retry_step",
        "elite_clan_get_team_stats_max_retry_time",
        "elite_clan_get_team_stats_retry_step",
        "elite_clan_motd_throttle_time",
        "elite_clan_remote_view_active",
        "elite_clan_remote_view_max_retry_time",
        "elite_clan_remote_view_retry_step",
        "elite_clan_send_message_to_members_max_retry_time",
        "elite_clan_send_message_to_members_retry_step",
        "elite_clan_set_private_member_profile_max_retry_time",
        "elite_clan_set_private_member_profile_retry_step",
        "elite_clan_single_task_popup_text",
        "elite_clan_using_title",
        "elite_edl",
        "elite_edl_xl",
        "enable_recordRecentActivity",
        "entitlements_active",
        "entitlements_config_file_max_retry_time",
        "entitlements_config_file_retry_step",
        "entitlements_cool_off_time",
        "entitlements_delay",
        "entitlements_key_archive_max_retry_time",
        "entitlements_key_archive_retry_step",
        "entitlementSystemOk",
        "extinction_cac_enabled",
        "extinction_hardcore_enabled",
        "extinction_intel_enabled",
        "extinction_map_selection_enabled",
        "extinction_tokens_enabled",
        "facebook_active",
        "facebook_delay",
        "facebook_friends_active",
        "facebook_friends_max_retry_time",
        "facebook_friends_refresh_time",
        "facebook_friends_retry_step",
        "facebook_friends_showing_count",
        "facebook_friends_throttle_time",
        "facebook_max_retry_time",
        "facebook_password",
        "facebook_password_asterisk",
        "facebook_popup_text",
        "facebook_retry_step",
        "facebook_upload_photo_active",
        "facebook_upload_video_active",
        "facebook_username",
        "fallback",
        "fixedtime",
        "FoFIconMaxSize",
        "FoFIconMinSize",
        "FoFIconScale",
        "friendlyfire_dev_disabled",
        "friendlyNameFontColor",
        "friendlyNameFontGlowColor",
        "friendlyNameFontObjective",
        "friendlyNameFontSize",
        "friendlyNameFontSizeSplitscreen",
        "friendlySaveFromDog",
        "friendsCacheSteamFriends",
        "friendsMaxSteamLookupsPerFrame",
        "friendsWidgetMinimumRefreshTimer",
        "fs_basegame",
        "fs_basepath",
        "fs_basepath_output",
        "fs_cdpath",
        "fs_copyfiles",
        "fs_debug",
        "fs_game",
        "fs_homepath",
        "fs_ignoreLocalized",
        "fx_alphaThreshold",
        "fx_count",
        "fx_cull_elem_draw",
        "fx_cull_elem_spawn",
        "fx_debugBolt",
        "fx_deferelem",
        "fx_draw",
        "fx_draw_omniLight",
        "fx_draw_simd",
        "fx_draw_spotLight",
        "fx_drawClouds",
        "fx_enable",
        "fx_freeze",
        "fx_killEffectOnRewind",
        "fx_mark_profile",
        "fx_marks",
        "fx_marks_ents",
        "fx_marks_smodels",
        "fx_profile",
        "fx_profileFilter",
        "fx_profileFilterElemCountZero",
        "fx_profileSkip",
        "fx_profileSort",
        "fx_visMinTraceDist",
        "g_ai",
        "g_aiAnimscript",
        "g_changelevel_time",
        "g_deathDelay",
        "g_disableBulletPenetration",
        "g_drawGrenadeHints",
        "g_earthquakeEnable",
        "g_fogColorIntensityReadOnly",
        "g_fogColorReadOnly",
        "g_fogHalfDistReadOnly",
        "g_fogMaxOpacityReadOnly",
        "g_fogStartDistReadOnly",
        "g_friendlyfireDamageScale",
        "g_friendlyfireDist",
        "g_friendlyNameDist",
        "g_gameskill",
        "g_gameskill_player_1",
        "g_gravity",
        "g_grenadeDamageMaxHeight",
        "g_keyboarduseholdtime",
        "g_knockback",
        "g_minGrenadeDamageSpeed",
        "g_onlyPlayerAreaEntities",
        "g_player_maxhealth",
        "g_reloading",
        "g_singleplayerAntilag",
        "g_spawnai",
        "g_speed",
        "g_sunFogBeginFadeAngleReadOnly",
        "g_sunFogColorIntensityReadOnly",
        "g_sunFogColorReadOnly",
        "g_sunFogDirReadOnly",
        "g_sunFogEnabledReadOnly",
        "g_sunFogEndFadeAngleReadOnly",
        "g_sunFogScaleReadOnly",
        "g_useholdtime",
        "gamedate",
        "gamedvr_active",
        "gameMode",
        "glass_angular_vel",
        "glass_break",
        "glass_crack_pattern_scale",
        "glass_damageToDestroy",
        "glass_damageToWeaken",
        "glass_edge_angle",
        "glass_fall_delay",
        "glass_fall_gravity",
        "glass_fall_ratio",
        "glass_fringe_maxcoverage",
        "glass_fringe_maxsize",
        "glass_fx_chance",
        "glass_hinge_friction",
        "glass_linear_vel",
        "glass_max_pieces_per_frame",
        "glass_max_shatter_fx_per_frame",
        "glass_meleeDamage",
        "glass_physics_chance",
        "glass_physics_maxdist",
        "glass_radiusDamageMultiplier",
        "glass_shard_maxsize",
        "glass_shattered_scale",
        "glass_simple_duration",
        "glass_trace_interval",
        "gpad_button_deadzone",
        "gpad_dpadDebounceTime",
        "gpad_menu_scroll_delay_first",
        "gpad_menu_scroll_delay_rest_accel",
        "gpad_menu_scroll_delay_rest_end",
        "gpad_menu_scroll_delay_rest_start",
        "gpad_stick_deadzone_max",
        "gpad_stick_deadzone_min",
        "gpad_stick_pressed",
        "gpad_stick_pressed_hysteresis",
        "grenadeBounceRestitutionMax",
        "grenadeBumpFreq",
        "grenadeBumpMag",
        "grenadeBumpMax",
        "grenadeCurveMax",
        "grenadeFrictionHigh",
        "grenadeFrictionLow",
        "grenadeFrictionMaxThresh",
        "grenadeRestThreshold",
        "grenadeRollingEnabled",
        "grenadeWobbleFreq",
        "grenadeWobbleFwdMag",
        "grenadeWobbleSideDamp",
        "grenadeWobbleSideMag",
        "groupDownloadInterval",
        "groupUploadInterval",
        "hiDef",
        "hideHudFast",
        "hostileNameFontColor",
        "hostileNameFontGlowColor",
        "hud_bloodOverlayLerpRate",
        "hud_deathQuoteFadeTime",
        "hud_drawHUD",
        "hud_fade_ammodisplay",
        "hud_fade_compass",
        "hud_fade_healthbar",
        "hud_fade_offhand",
        "hud_fade_sprint",
        "hud_fade_stance",
        "hud_flash_period_offhand",
        "hud_flash_time_offhand",
        "hud_forceMantleHint",
        "hud_health_pulserate_critical",
        "hud_health_pulserate_injured",
        "hud_health_startpulse_critical",
        "hud_health_startpulse_injured",
        "hud_letterBoxFadeTime",
        "hud_missionFailed",
        "hud_showIntel",
        "hud_showObjectives",
        "hud_showStance",
        "hudElemPausedBrightness",
        "igs_announcer",
        "igs_crossgame",
        "igs_fo",
        "igs_s1",
        "igs_shp",
        "igs_smappacks",
        "igs_sosp",
        "igs_sripper",
        "igs_sve",
        "igs_svp",
        "igs_svr",
        "igs_svs",
        "igs_swap",
        "igs_swp",
        "igs_td",
        "in_mouse",
        "intro",
        "jump_height",
        "laserDebug",
        "laserEndOffset",
        "laserFlarePct",
        "laserFlarePct_alt",
        "laserLight",
        "laserLightBeginOffset",
        "laserLightBodyTweak",
        "laserLightEndOffset",
        "laserLightRadius",
        "laserLightRadius_alt",
        "laserLightWithoutNightvision",
        "laserRadius",
        "laserRadius_alt",
        "laserRange",
        "laserRange_alt",
        "laserRangePlayer",
        "lb_file",
        "lb_filter",
        "lb_filter_duration",
        "lb_maxrows",
        "lb_minrefresh",
        "lb_readDelay",
        "lb_throttle_time",
        "lb_times_in_window",
        "lb_window",
        "live_displayLogOnErrorReason",
        "live_qosec_firstupdatems",
        "live_qosec_lastupdatems",
        "live_qosec_maxtime",
        "live_qosec_minpercent",
        "live_qosec_minprobes",
        "livestreaming_active",
        "loading_sre_fatal",
        "loc_language",
        "loc_translate",
        "log_host_migration_chance",
        "log_mapvote_chance",
        "log_teambalance_chance",
        "lowAmmoWarningColor1",
        "lowAmmoWarningColor2",
        "lowAmmoWarningNoAmmoColor1",
        "lowAmmoWarningNoAmmoColor2",
        "lowAmmoWarningNoReloadColor1",
        "lowAmmoWarningNoReloadColor2",
        "lowAmmoWarningPulseFreq",
        "lowAmmoWarningPulseMax",
        "lowAmmoWarningPulseMin",
        "lsp_enumertion_max_retry_time",
        "lsp_enumertion_retry_step",
        "lui_FFotDSupportEnabled",
        "LUI_MemErrorsFatal",
        "lui_menuFlowEnabled",
        "lui_pausemenu",
        "lui_splitscreensignin_menu",
        "lui_splitscreenupscaling",
        "lui_systemlink_menu",
        "LUI_WorkerCmdGC",
        "lui_xboxlive_menu",
        "m_filter",
        "m_forward",
        "m_pitch",
        "m_side",
        "m_vehMouseSteerSensitivity",
        "m_yaw",
        "mantle_anim_rate_max",
        "mantle_check_angle",
        "mantle_check_radius",
        "mantle_check_range",
        "mantle_check_range_smooth",
        "mantle_enable",
        "mantle_end_height_tolerance",
        "mantle_max_time",
        "mantle_max_vertical_end_velocity",
        "mantle_min_over_dist",
        "mantle_over_dist_16",
        "mantle_over_dist_24",
        "mantle_over_dist_32",
        "mantle_over_dist_40",
        "mantle_over_dist_48",
        "mantle_over_dist_56",
        "mantle_over_dist_64",
        "mantle_over_height_offset",
        "mantle_pitch_default_contact_time",
        "mantle_pitch_default_return_time_on",
        "mantle_pitch_default_return_time_over",
        "mantle_pitch_return_lerp_time",
        "mantle_use_approach_angle",
        "mantle_view_yawcap",
        "mapname",
        "mapvote_logging",
        "match_making_telemetry_chance",
        "matchdata_active",
        "matchdata_maxcompressionbuffer",
        "matchmaking_debug",
        "maxVoicePacketsPerSec",
        "maxVoicePacketsPerSecForServer",
        "mdsd",
        "melee_debug",
        "mgTurret",
        "minimap_full_sp",
        "minimap_sp",
        "mis_cheat",
        "missileExplosionLiftDistance",
        "missileGlassShatterVel",
        "missileHellfireMaxSlope",
        "missileHellfireUpAccel",
        "missileJavAccelClimb",
        "missileJavAccelDescend",
        "missileJavClimbAngleDirect",
        "missileJavClimbAngleTop",
        "missileJavClimbCeilingDirect",
        "missileJavClimbCeilingTop",
        "missileJavClimbHeightDirect",
        "missileJavClimbHeightTop",
        "missileJavClimbToOwner",
        "missileJavDuds",
        "missileJavSpeedLimitClimb",
        "missileJavSpeedLimitDescend",
        "missileJavTurnDecel",
        "missileJavTurnRateDirect",
        "missileJavTurnRateTop",
        "missileMacross",
        "missileRemoteFOV",
        "missileRemoteSpeedDown",
        "missileRemoteSpeedTargetRange",
        "missileRemoteSpeedUp",
        "missileRemoteSteerPitchRange",
        "missileRemoteSteerPitchRate",
        "missileRemoteSteerYawRate",
        "missileWaterMaxDepth",
        "monkeytoy",
        "motd",
        "Support",
        "Follow",
        "Visit",
        "motd_store_link",
        "motionTrackerBlurDuration",
        "motionTrackerCenterX",
        "motionTrackerCenterY",
        "motionTrackerPingFadeTime",
        "motionTrackerPingPitchAddPerEnemy",
        "motionTrackerPingPitchBase",
        "motionTrackerPingPitchNearby",
        "motionTrackerPingSize",
        "motionTrackerRange",
        "motionTrackerSweepInterval",
        "motionTrackerSweepSpeed",
        "moving_platform_rotational_antilag",
        "music_enable",
        "name",
        "net_authPort",
        "net_ip",
        "net_masterServerPort",
        "net_noudp",
        "net_port",
        "net_socksEnabled",
        "net_socksPassword",
        "net_socksPort",
        "net_socksServer",
        "net_socksUsername",
        "netinfo_logging",
        "nextmap",
        "nightVisionDisableEffects",
        "nightVisionFadeInOutTime",
        "nightVisionPowerOnTime",
        "noai",
        "num_available_map_packs",
        "objectiveAlpha",
        "objectiveAlphaEnabled",
        "objectiveArrowHeight",
        "objectiveArrowWidth",
        "objectiveColor",
        "objectiveFadeTimeGoingOff",
        "objectiveFadeTimeGoingOn",
        "objectiveFadeTimeWaitOff",
        "objectiveFadeTimeWaitOn",
        "objectiveFadeTooClose",
        "objectiveFadeTooFar",
        "objectiveFontSize",
        "objectiveHide",
        "objectiveHideIcon",
        "objectiveTextOffsetY",
        "overrideNVGModelWithKnife",
        "painVisionLerpInRate",
        "painVisionLerpOutRate",
        "past_title_data_active",
        "past_title_data_read_failure_interval_hours",
        "past_title_data_read_success_interval_hours",
        "perk_bulletPenetrationMultiplier",
        "perk_extendedMagsMGAmmo",
        "perk_extendedMagsPistolAmmo",
        "perk_extendedMagsRifleAmmo",
        "perk_extendedMagsSMGAmmo",
        "perk_extendedMagsSpreadAmmo",
        "perk_extraBreath",
        "perk_fastSnipeScale",
        "perk_footstepVolumeAlly",
        "perk_footstepVolumeEnemy",
        "perk_footstepVolumePlayer",
        "perk_footstepVolumeSelectiveHearingMin",
        "perk_grenadeDeath",
        "perk_improvedExtraBreath",
        "perk_lightWeightViewBobScale",
        "perk_parabolicAngle",
        "perk_parabolicIcon",
        "perk_parabolicRadius",
        "perk_quickDrawSpeedScale",
        "perk_sprintMultiplier",
        "perk_sprintRecoveryMultiplierActual",
        "perk_sprintRecoveryMultiplierVisual",
        "perk_weapRateMultiplier",
        "perk_weapReloadMultiplier",
        "perk_weapSpreadMultiplier",
        "phys_autoDisableAngular",
        "phys_autoDisableFastAngular",
        "phys_autoDisableFastLinear",
        "phys_autoDisableFastTime",
        "phys_autoDisableLinear",
        "phys_autoDisableTime",
        "phys_bulletSpinScale",
        "phys_bulletUpBias",
        "phys_cfm",
        "phys_collUseEntities",
        "phys_contact_cfm",
        "phys_contact_cfm_ragdoll",
        "phys_contact_cfm_vehicle",
        "phys_contact_cfm_vehicleSoft",
        "phys_contact_erp",
        "phys_contact_erp_ragdoll",
        "phys_contact_erp_vehicle",
        "phys_contact_erp_vehicleSoft",
        "phys_csl",
        "phys_dragAngular",
        "phys_dragLinear",
        "phys_erp",
        "phys_frictionScale",
        "phys_gravity",
        "phys_gravity_ragdoll",
        "phys_gravityChangeWakeupRadius",
        "phys_jitterMaxMass",
        "phys_joint_cfm",
        "phys_joint_stop_cfm",
        "phys_joint_stop_erp",
        "phys_jointPullThreshold",
        "phys_mcv",
        "phys_mcv_ragdoll",
        "phys_mcv_vehicle",
        "phys_noIslands",
        "phys_qsi",
        "phys_reorderConst",
        "physVeh_collideWithClipOnly",
        "physVeh_explodeForce",
        "physVeh_explodeSpinScale",
        "physVeh_jump",
        "physVeh_minImpactMomentum",
        "physVeh_pathConstraintCfm",
        "physVeh_pathConstraintErp",
        "physVeh_slideReductionForHighSpeed",
        "physVeh_StepsPerFrame",
        "pickupPrints",
        "player_breath_snd_delay",
        "player_breath_snd_lerp",
        "player_cheated",
        "player_damageMultiplier",
        "player_deathInvulnerableToMelee",
        "player_deathInvulnerableToProjectile",
        "player_died_recently",
        "player_lateralPlane",
        "player_meleeChargeFriction",
        "player_meleeChargeHeightTolerance",
        "player_meleeChargeMaxSpeed",
        "player_meleeChargeMaxSpeedUp",
        "player_meleeDamageMultiplier",
        "player_meleeHeight",
        "player_meleeIdealEndDistance",
        "player_meleeMaxQuickRaiseTime",
        "player_meleeMinimumResponseGraceTime",
        "player_meleeRange",
        "player_meleeRangeCharge",
        "player_meleeSwipeViewLockReleaseTime",
        "player_meleeWidth",
        "player_MGUseRadius",
        "player_moveThreshhold",
        "player_radiusDamageMultiplier",
        "player_spaceCapsuleHeight",
        "player_spaceEnabled",
        "player_spaceViewHeight",
        "player_sprintJumpAnimRate",
        "player_sprintJumpDropWeaponScaler",
        "player_sprintSpeedScale",
        "player_sprintUnlimited",
        "player_swimAcceleration",
        "player_swimCombatTimer",
        "player_swimDragHandFrictionMax",
        "player_swimDragHandFrictionMin",
        "player_swimDragHandLookAtOffset",
        "player_swimForwardAnimCatchupMax",
        "player_swimForwardAnimCatchupMin",
        "player_swimForwardMinAngle",
        "player_swimForwardMinSpeed",
        "player_swimForwardSettleTime",
        "player_swimForwardWarmupTime",
        "player_swimFriction",
        "player_swimSpeed",
        "player_swimVerticalAcceleration",
        "player_swimVerticalFriction",
        "player_swimVerticalSpeed",
        "player_swimWaterCurrent",
        "player_throwbackInnerRadius",
        "player_throwbackOuterRadius",
        "player_useRadius",
        "player_view_pitch_down",
        "player_view_pitch_up",
        "playercard_cache_download_max_retry_time",
        "playercard_cache_download_retry_step",
        "playercard_cache_upload_max_retry_time",
        "playercard_cache_upload_retry_step",
        "playercard_cache_validity_life",
        "pm_bouncing",
        "pm_gamesetup_mode_altmodes",
        "pm_gamesetup_mode_altmodes_dropzone",
        "pm_gamesetup_mode_altmodes_gungame",
        "pm_gamesetup_mode_altmodes_infected",
        "pm_gamesetup_mode_altmodes_jug",
        "pm_gamesetup_mode_altmodes_mugger",
        "pm_gamesetup_mode_altmodes_oneinthechamber",
        "pm_gamesetup_mode_altmodes_teamjug",
        "pm_gamesetup_options_createdefaultclass",
        "pm_gamesetup_options_customclassrestrictions",
        "prestige_shop_active",
        "profileMenuOption_blacklevel",
        "profileMenuOption_offensiveContentMode",
        "profileMenuOption_safeAreaHorz",
        "profileMenuOption_safeAreaVert",
        "profileMenuOption_sensitivity",
        "profileMenuOption_volume",
        "prologue_select",
        "r_aaMode",
        "r_adaptiveSubdiv",
        "r_adaptiveSubdivBaseFactor",
        "r_adaptiveSubdivPatchFactor",
        "r_altModelLightingUpdate",
        "r_amdGPU",
        "r_amdGPUVideoMemoryScale",
        "r_apex_turbulence",
        "r_apexTurbulence_LOD_MaxDist",
        "r_apexTurbulence_LOD_MinDist",
        "r_apexTurbulence_LOD_MinPercent",
        "r_artUseTweaks",
        "r_aspectRatio",
        "r_aspectRatioCustom",
        "r_asyncCompute",
        "r_atlasAnimFPS",
        "r_autopriority",
        "r_blacklevel",
        "r_blur",
        "r_brightness",
        "r_cacheModelLighting",
        "r_cacheSModelLighting",
        "r_cc_contrastPow1",
        "r_cc_contrastPow2",
        "r_cc_contrastScale1",
        "r_cc_contrastScale2",
        "r_cc_desaturation1",
        "r_cc_desaturation2",
        "r_cc_lerp1",
        "r_cc_lerp2",
        "r_cc_mode",
        "r_cc_toneBias1",
        "r_cc_toneBias2",
        "r_charLightAmbient",
        "r_charLightAmbient_NG",
        "r_clampLodScale",
        "r_clear",
        "r_clearColor",
        "r_clearColor2",
        "r_cmdbuf_worker",
        "r_colorGradingEnable",
        "r_colorMap",
        "r_combinePostOpaqueFx",
        "r_contrast",
        "r_debugLineWidth",
        "r_defaultPatchCount",
        "r_depthPrepass",
        "r_desaturation",
        "r_detailMap",
        "r_diffuseColorScale",
        "r_displacementMap",
        "r_displacementPatchCount",
        "r_displayMaxHeight",
        "r_displayMaxWidth",
        "r_displayMode",
        "r_displayRefresh",
        "r_distortion",
        "r_dlightLimit",
        "r_dof_bias",
        "r_dof_enable",
        "r_dof_farBlur",
        "r_dof_farEnd",
        "r_dof_farStart",
        "r_dof_hq",
        "r_dof_nearBlur",
        "r_dof_nearEnd",
        "r_dof_nearStart",
        "r_dof_tweak",
        "r_dof_viewModelEnd",
        "r_dof_viewModelStart",
        "r_drawSun",
        "r_drawWater",
        "r_elevatedPriority",
        "r_envMapExponent",
        "r_envMapMaxIntensity",
        "r_envMapMinIntensity",
        "r_envMapOverride",
        "r_envMapSunIntensity",
        "r_fastModelPrimaryLightCheck",
        "r_fastModelPrimaryLightLink",
        "r_filmAltShader",
        "r_filmTweakBrightness",
        "r_filmTweakContrast",
        "r_filmTweakDarkTint",
        "r_filmTweakDesaturation",
        "r_filmTweakDesaturationDark",
        "r_filmTweakEnable",
        "r_filmTweakInvert",
        "r_filmTweakLightTint",
        "r_filmTweakMediumTint",
        "r_filmUseTweaks",
        "r_flushAfterExecute",
        "r_fog",
        "r_fog_depthhack_scale",
        "r_forceLetterbox4x3",
        "r_forceLod",
        "r_fullbright",
        "r_fur_shader",
        "r_fxaaSubpixel",
        "r_FXAverageColorFunc",
        "r_glare_amountMin",
        "r_glare_enable",
        "r_glare_mergeWithBloom",
        "r_glare_mirrorAmount",
        "r_glare_mirrorEnd",
        "r_glare_mirrorPower",
        "r_glare_mirrorStart",
        "r_glare_normalAmount",
        "r_glare_normalEnd",
        "r_glare_normalPower",
        "r_glare_normalStart",
        "r_glare_useTweaks",
        "r_globalGenericMaterialScale",
        "r_glow_allowed",
        "r_glow_allowed_script_forced",
        "r_hbaoBias",
        "r_hbaoBlurEnable",
        "r_hbaoBlurSharpness",
        "r_hbaoCoarseAO",
        "r_hbaoDebug",
        "r_hbaoDetailAO",
        "r_hbaoPowerExponent",
        "r_hbaoRadius",
        "r_hbaoSceneScale",
        "r_hbaoStrengthBlend",
        "r_hbaoStrengthFixed",
        "r_hbaoStrengthScale",
        "r_hbaoUseScriptScale",
        "r_hdrColorizationBeforeEmissive",
        "r_hdrSkyColorTint",
        "r_hdrSkyIntensity",
        "r_hdrSkyIntensityUseTweaks",
        "r_heroLighting",
        "r_highLodDist",
        "r_hudOutlineAlpha0",
        "r_hudOutlineAlpha1",
        "r_hudOutlineCurvyBlurRadius",
        "r_hudOutlineCurvyDarkenScale",
        "r_hudOutlineCurvyDepth",
        "r_hudOutlineCurvyLumScale",
        "r_hudOutlineCurvyWhen",
        "r_hudOutlineCurvyWidth",
        "r_hudOutlineEnable",
        "r_hudOutlineHaloBlurRadius",
        "r_hudOutlineHaloDarkenScale",
        "r_hudOutlineHaloLumScale",
        "r_hudOutlineHaloWhen",
        "r_hudOutlinePostMode",
        "r_hudOutlineWhen",
        "r_hudOutlineWidth",
        "r_ignore",
        "r_ignoref",
        "r_imageQuality",
        "r_lateAllocParamCacheAllowed",
        "r_lateAllocParamCacheDefault",
        "r_lateAllocParamCacheDisplacement",
        "r_lateAllocParamCacheSubdiv",
        "r_letterbox4x3",
        "r_lightCacheLessFrequentMaxDistance",
        "r_lightCacheLessFrequentPeriod",
        "r_lightGridContrast",
        "r_lightGridEnableTweaks",
        "r_lightGridIntensity",
        "r_lightGridSHBands",
        "r_lightGridUseTweakedValues",
        "r_lightMap",
        "r_litSurfaceHDRScalar",
        "r_loadForRenderer",
        "r_lockPvs",
        "r_lod4Dist",
        "r_lod5Dist",
        "r_lodBiasRigid",
        "r_lodBiasSkinned",
        "r_lodScaleRigid",
        "r_lodScaleSkinned",
        "r_lowestLodDist",
        "r_lowLodDist",
        "r_materialBloomDesaturation",
        "r_materialBloomHQDesaturation",
        "r_materialBloomHQEnable",
        "r_materialBloomHQFalloffScale1",
        "r_materialBloomHQFalloffScale2",
        "r_materialBloomHQFalloffWeight1",
        "r_materialBloomHQFalloffWeight2",
        "r_materialBloomHQGamma",
        "r_materialBloomHQHaziness",
        "r_materialBloomHQRadius",
        "r_materialBloomHQScriptMasterEnable",
        "r_materialBloomHQSensitivity",
        "r_materialBloomIntensity",
        "r_materialBloomLuminanceCutoff",
        "r_materialBloomPinch",
        "r_materialBloomRadius",
        "r_materialBloomUseTweaks",
        "r_mbCameraRotationInfluence",
        "r_mbCameraTranslationInfluence",
        "r_mbEnable",
        "r_mbEnableA",
        "r_mbFastEnable",
        "r_mbFastEnableA",
        "r_mbFastPreset",
        "r_mbModelVelocityScalar",
        "r_mbPostfxMaxNumSamples",
        "r_mbStaticVelocityScalar",
        "r_mbViewModelEnable",
        "r_mbViewModelVelocityScalar",
        "r_mediumLodDist",
        "r_mode",
        "r_monitor",
        "r_msaaEnable",
        "r_msaaResolveMode",
        "r_multiGPU",
        "r_normalMap",
        "r_nvidiaGPU",
        "r_nvidiaGPUCount",
        "r_offchipTessellationAllowed",
        "r_offchipTessellationTfThreshold",
        "r_offchipTessellationWaveThreshold",
        "r_omitUnusedRenderTargets",
        "r_outdoor",
        "r_outdoorFeather",
        "r_patchCountAllowed",
        "r_picmip",
        "r_picmip_bump",
        "r_picmip_manual",
        "r_picmip_spec",
        "r_picmip_water",
        "r_polygonOffsetBias",
        "r_polygonOffsetClamp",
        "r_polygonOffsetScale",
        "r_portalBevels",
        "r_portalBevelsOnly",
        "r_portalMinClipArea",
        "r_portalMinRecurseDepth",
        "r_portalWalkLimit",
        "r_postAA",
        "r_postfxMacroclutEnable",
        "r_postfxMacroclutWorker",
        "r_preloadShaders",
        "r_primaryLightTweakDiffuseStrength",
        "r_primaryLightTweakDiffuseStrength_NG",
        "r_primaryLightTweakSpecularStrength",
        "r_primaryLightTweakSpecularStrength_NG",
        "r_primaryLightUseTweaks",
        "r_primaryLightUseTweaks_NG",
        "r_reactiveMotionActorRadius",
        "r_reactiveMotionActorVelocityMax",
        "r_reactiveMotionEffectorStrengthScale",
        "r_reactiveMotionHelicopterLimit",
        "r_reactiveMotionHelicopterRadius",
        "r_reactiveMotionHelicopterStrength",
        "r_reactiveMotionPlayerHeightAdjust",
        "r_reactiveMotionPlayerRadius",
        "r_reactiveMotionVelocityTailScale",
        "r_reactiveMotionWindAmplitudeScale",
        "r_reactiveMotionWindAreaScale",
        "r_reactiveMotionWindDir",
        "r_reactiveMotionWindFrequencyScale",
        "r_reactiveMotionWindStrength",
        "r_reactiveTurbulenceActorRadius",
        "r_reactiveTurbulenceEnable",
        "r_reactiveTurbulenceMissileLifetime",
        "r_reactiveTurbulenceMissileMaxLength",
        "r_reactiveTurbulenceMissileRadius",
        "r_reactiveTurbulenceMissileVelocityScale",
        "r_reactiveTurbulenceVelocityClamp",
        "r_rendererInUse",
        "r_rimLight0Color",
        "r_rimLight0Heading",
        "r_rimLight0Pitch",
        "r_rimLightBias",
        "r_rimLightDiffuseIntensity",
        "r_rimLightPower",
        "r_rimLightSpecIntensity",
        "r_rimLightUseTweaks",
        "r_scaleViewport",
        "r_showBlurScene",
        "r_showBlurSceneScissor",
        "r_showLightGrid",
        "r_showMissingLightGrid",
        "r_showModelLightingLowWaterMark",
        "r_showPIPTexture",
        "r_showPortals",
        "r_showPortalsOverview",
        "r_showReflectionProbeSelection",
        "r_singleCell",
        "r_SkinnedCacheSize",
        "r_SkinnedCacheThreshold",
        "r_skipPvs",
        "r_sky_fog_intensity",
        "r_sky_fog_max_angle",
        "r_sky_fog_min_angle",
        "r_skyFogUseTweaks",
        "r_smaaThreshold",
        "r_smodelInstancedRenderer",
        "r_smodelInstancedThreshold",
        "r_smp_backend",
        "r_smp_worker",
        "r_smp_worker_thread0",
        "r_smp_worker_thread1",
        "r_smp_worker_thread2",
        "r_smp_worker_thread3",
        "r_smp_worker_thread4",
        "r_smp_worker_thread5",
        "r_smp_worker_thread6",
        "r_smp_worker_thread7",
        "r_snowAmbientColor",
        "r_specularColorScale",
        "r_specularMap",
        "r_spotLightEntityShadows",
        "r_spotLightShadows",
        "r_ssao",
        "r_ssaoBlurSharpness",
        "r_ssaoBlurStep",
        "r_ssaoDepthScale",
        "r_ssaoDepthScaleViewModel",
        "r_ssaoDiminish",
        "r_ssaoFadeDepth",
        "r_ssaoGapFalloff",
        "r_ssaoGradientFalloff",
        "r_ssaoMinPixelWidth",
        "r_ssaoPower",
        "r_ssaoRejectDepth",
        "r_ssaoScriptScale",
        "r_ssaoStrength",
        "r_ssaoUseScriptScale",
        "r_ssaoUseTweaks",
        "r_ssaoWidth",
        "r_sse_skinning",
        "r_ssrFadeInDuration",
        "r_ssrPositionCorrection",
        "r_subdiv",
        "r_subdivLimit",
        "r_subdivPatchCount",
        "r_subdomainLimit",
        "r_subdomainScale",
        "r_subwindow",
        "r_sun_from_dvars",
        "r_sun_fx_position",
        "r_sunblind_fadein",
        "r_sunblind_fadeout",
        "r_sunblind_max_angle",
        "r_sunblind_max_darken",
        "r_sunblind_min_angle",
        "r_sunflare_fadein",
        "r_sunflare_fadeout",
        "r_sunflare_max_alpha",
        "r_sunflare_max_angle",
        "r_sunflare_max_size",
        "r_sunflare_min_angle",
        "r_sunflare_min_size",
        "r_sunflare_position",
        "r_sunflare_shader",
        "r_sunglare_fadein",
        "r_sunglare_fadeout",
        "r_sunglare_max_angle",
        "r_sunglare_max_lighten",
        "r_sunglare_min_angle",
        "r_sunshadowmap_cmdbuf_worker",
        "r_sunsprite_shader",
        "r_sunsprite_size",
        "r_sunsprite_size_override",
        "r_surfaceHDRScalarUseTweaks",
        "r_tessellation",
        "r_tessellationCutoffDistance",
        "r_tessellationCutoffDistanceBase",
        "r_tessellationCutoffFalloff",
        "r_tessellationCutoffFalloffBase",
        "r_tessellationEyeScale",
        "r_tessellationFactor",
        "r_tessellationHeightAuto",
        "r_tessellationHeightScale",
        "r_tessellationHybrid",
        "r_tessellationLodBias",
        "r_texFilterAnisoMax",
        "r_texFilterAnisoMin",
        "r_texFilterDisable",
        "r_texFilterMipBias",
        "r_texFilterMipMode",
        "r_texFilterProbeBilinear",
        "r_texShowMipMode",
        "r_thermalColorOffset",
        "r_thermalColorScale",
        "r_thermalDetailScale",
        "r_thermalFadeColor",
        "r_thermalFadeControl",
        "r_thermalFadeMax",
        "r_thermalFadeMin",
        "r_txaa",
        "r_txaaDebug",
        "r_txaaDepthRange",
        "r_txaaLimitPixels1",
        "r_txaaLimitPixels2",
        "r_umbra",
        "r_umbraAccurateOcclusionThreshold",
        "r_umbraDistanceReference",
        "r_umbraExclusive",
        "r_umbraQueryParts",
        "r_umbraShadowCasters",
        "r_umbraUseDpvsCullDist",
        "r_unlitSurfaceHDRScalar",
        "r_useComputeSkinning",
        "r_useLayeredMaterials",
        "r_usePrebuiltSpotShadow",
        "r_usePrebuiltSunShadow",
        "r_useShadowGeomOpt",
        "r_vc_makelog",
        "r_vc_showlog",
        "r_viewModelLightAmbient",
        "r_viewModelLightAmbient_NG",
        "r_viewModelPrimaryLightTweakDiffuseStrength",
        "r_viewModelPrimaryLightTweakDiffuseStrength_NG",
        "r_viewModelPrimaryLightTweakSpecularStrength",
        "r_viewModelPrimaryLightTweakSpecularStrength_NG",
        "r_viewModelPrimaryLightUseTweaks",
        "r_viewModelPrimaryLightUseTweaks_NG",
        "r_volumeLightScatter",
        "r_volumeLightScatterAngularAtten",
        "r_volumeLightScatterBackgroundDistance",
        "r_volumeLightScatterColor",
        "r_volumeLightScatterDepthAttenFar",
        "r_volumeLightScatterDepthAttenNear",
        "r_volumeLightScatterLinearAtten",
        "r_volumeLightScatterQuadraticAtten",
        "r_volumeLightScatterUseTweaks",
        "r_vsync",
        "r_warningRepeatDelay",
        "r_zfar",
        "r_znear",
        "radarjamDistMax",
        "radarjamDistMin",
        "radarjamSinCurve",
        "radius_damage_debug",
        "ragdoll_baselerp_time",
        "ragdoll_bullet_force",
        "ragdoll_bullet_upbias",
        "ragdoll_debug",
        "ragdoll_debug_axisid",
        "ragdoll_debug_bodyid",
        "ragdoll_debug_boneid",
        "ragdoll_debug_jointid",
        "ragdoll_dump_anims",
        "ragdoll_enable",
        "ragdoll_explode_force",
        "ragdoll_explode_upbias",
        "ragdoll_exploding_bullet_force",
        "ragdoll_exploding_bullet_upbias",
        "ragdoll_fps",
        "ragdoll_idle_min_velsq",
        "ragdoll_jitter_scale",
        "ragdoll_jointlerp_time",
        "ragdoll_max_life",
        "ragdoll_max_simulating",
        "ragdoll_max_stretch_pct",
        "ragdoll_mp_limit",
        "ragdoll_rotvel_scale",
        "ragdoll_self_collision_scale",
        "ragdoll_stretch_iters",
        "RemoteCameraSounds_DryLevel",
        "RemoteCameraSounds_RoomType",
        "RemoteCameraSounds_WetLevel",
        "requireOpenNat",
        "requirestats",
        "reset_mm_data",
        "safeArea_adjusted_horizontal",
        "safeArea_adjusted_vertical",
        "safeArea_horizontal",
        "safeArea_vertical",
        "scr_dof_enable",
        "scr_expDeathMayMoveCheck",
        "scr_RequiredMapAspectratio",
        "screenshots_active",
        "sensitivity",
        "sentry_placement_debug",
        "sentry_placement_feet_offset",
        "sentry_placement_feet_trace_dist_z",
        "sentry_placement_trace_dist",
        "sentry_placement_trace_min_normal",
        "sentry_placement_trace_pitch",
        "sentry_placement_trace_radius",
        "sentry_placement_trace_radius_canon_safety",
        "serverCulledSounds",
        "session_immediateDeleteTinySessions",
        "session_modify_retry_on_failure",
        "session_nonblocking",
        "shieldBlastDamageProtection_120",
        "shieldBlastDamageProtection_180",
        "shieldBlastDamageProtection_30",
        "shieldBlastDamageProtection_60",
        "shieldImpactBulletShakeDuration",
        "shieldImpactBulletShakeScale",
        "shieldImpactExplosionHighShakeDuration",
        "shieldImpactExplosionHighShakeScale",
        "shieldImpactExplosionLowShakeDuration",
        "shieldImpactExplosionLowShakeScale",
        "shieldImpactExplosionThreshold",
        "shieldImpactMissileShakeDuration",
        "shieldImpactMissileShakeScale",
        "shieldPlayerBulletProtectionDegrees",
        "slide_enable",
        "slide_skip_hold",
        "sm_cameraOffset",
        "sm_dynlightAllSModels",
        "sm_enable",
        "sm_fastSunShadow",
        "sm_lightScore_eyeProjectDist",
        "sm_lightScore_spotProjectFrac",
        "sm_maxLightsWithShadows",
        "sm_minSpotLightScore",
        "sm_polygonOffsetBias",
        "sm_polygonOffsetClamp",
        "sm_polygonOffsetScale",
        "sm_qualitySpotShadow",
        "sm_spotDistCull",
        "sm_spotEnable",
        "sm_spotLightScoreModelScale",
        "sm_spotLimit",
        "sm_spotShadowFadeTime",
        "sm_strictCull",
        "sm_sunEnable",
        "sm_sunSampleSizeNear",
        "sm_sunShadowCenter",
        "sm_sunShadowCenterMode",
        "sm_sunShadowScale",
        "sm_sunShadowScaleLocked",
        "snd_cinematicVolumeScale",
        "snd_dopplerAuditionEnable",
        "snd_dopplerBaseSpeedOfSound",
        "snd_dopplerEnable",
        "snd_dopplerPitchMax",
        "snd_dopplerPitchMin",
        "snd_dopplerPlayerVelocityScale",
        "snd_dopplerSmoothing",
        "snd_draw3D",
        "snd_drawInfo",
        "snd_enable2D",
        "snd_enable3D",
        "snd_enableEq",
        "snd_enableReverb",
        "snd_enableStream",
        "snd_errorOnMissing",
        "snd_levelFadeTime",
        "snd_loadFadeTime",
        "snd_newWhizby",
        "snd_occlusionDelay",
        "snd_occlusionEnabled",
        "snd_occlusionLerpTime",
        "snd_omnidirectionalPercentage",
        "snd_slaveFadeTime",
        "snd_touchStreamFilesOnLoad",
        "snd_useHardOuterEntchannelPriorities",
        "snd_volume",
        "so_survival",
        "social_feed_clans_active",
        "social_feed_motd_active",
        "social_feed_news_active",
        "social_feed_social_active",
        "social_feed_squads_active",
        "solo_play",
        "specialops",
        "specops_map_groupnum",
        "specops_map_itemnum",
        "speech_active",
        "splitscreen",
        "squad_cile",
        "squad_find_match_max_retry_time",
        "squad_find_match_retry_step",
        "squad_rxb",
        "squad_rxbm",
        "start",
        "start_timeaa_main_deer_hunt",
        "starting_ads_damage_dealtaa_main_deer_hunt",
        "starting_deathsaa_main_deer_hunt",
        "starting_enemy_damage_takenaa_main_deer_hunt",
        "starting_enemy_deathsaa_main_deer_hunt",
        "starting_player_damage_dealtaa_main_deer_hunt",
        "starting_player_damage_takenaa_main_deer_hunt",
        "starting_player_killsaa_main_deer_hunt",
        "steam_ingame_p2p_throttle",
        "steve",
        "stringtable_debug",
        "sv_framerate_smoothing",
        "sv_loadingsavegame",
        "sv_running",
        "sv_savegametransient",
        "sv_saveOnStartMap",
        "sv_znear",
        "svwp",
        "sys_configSum",
        "sys_configureGHz",
        "sys_cpuGHz",
        "sys_cpuName",
        "sys_gpu",
        "sys_lockThreads",
        "sys_quitMigrateTime",
        "sys_smp_allowed",
        "sys_SSE",
        "sys_sysMB",
        "systemlink",
        "theater_active",
        "thermalBlurFactorNoScope",
        "thermalBlurFactorScope",
        "timescale",
        "tracer_explosiveColor1",
        "tracer_explosiveColor2",
        "tracer_explosiveColor3",
        "tracer_explosiveColor4",
        "tracer_explosiveColor5",
        "tracer_explosiveOverride",
        "tracer_explosiveWidth",
        "tracer_firstPersonMaxWidth",
        "tracer_thermalWidthMult",
        "traceScheduler_throttleTraces",
        "transients_verbose",
        "turret_adsEnabled",
        "turret_adsTime",
        "turretPlayerAvoidScale",
        "turretSentryRestrictUsageToOwner",
        "ui_actionSlot_1_forceActive",
        "ui_actionSlot_2_forceActive",
        "ui_actionSlot_3_forceActive",
        "ui_actionSlot_4_forceActive",
        "ui_autoContinue",
        "ui_autodetectGamepad",
        "ui_autodetectGamepadDone",
        "ui_bigFont",
        "ui_borderLowLightScale",
        "ui_buildLocation",
        "ui_buildSize",
        "ui_campaign",
        "ui_cg_fov",
        "ui_cinematicsTimestamp",
        "ui_contextualMenuLocation",
        "ui_debugMode",
        "ui_disableInGameStore",
        "ui_disableTokenRedemption",
        "ui_dog_grenade",
        "ui_extraBigFont",
        "ui_hideMap",
        "ui_inSpecOpsLeaderboards",
        "ui_is_so_dlc",
        "ui_isSaving",
        "ui_level_cheatpoints",
        "ui_level_player_cheatpoints",
        "ui_mousePitch",
        "ui_multiplayer",
        "ui_myPartyColor",
        "ui_nextMission",
        "ui_online_coop",
        "ui_play_credits",
        "ui_pmc_won",
        "ui_r_aaMode",
        "ui_r_apex_turbulence",
        "ui_r_aspectratio",
        "ui_r_displayMode",
        "ui_r_displayrefresh",
        "ui_r_distortion",
        "ui_r_dof_enable",
        "ui_r_fur_shader",
        "ui_r_imageQuality",
        "ui_r_mbEnableA",
        "ui_r_mode",
        "ui_r_picmip",
        "ui_r_picmip_bump",
        "ui_r_picmip_manual",
        "ui_r_picmip_spec",
        "ui_r_picmip_water",
        "ui_r_ssao",
        "ui_r_tessellation",
        "ui_r_texFilterAnisoMin",
        "ui_r_vsync",
        "ui_remotemissile_playernum",
        "ui_savegame",
        "ui_saveMessageMinTime",
        "ui_securing",
        "ui_securing_progress",
        "ui_selectedFeederMap",
        "ui_showList",
        "ui_showMenuOnly",
        "ui_skip_initial_game_mode",
        "ui_sliderSteps",
        "ui_sm_enable",
        "ui_smallFont",
        "ui_textScrollFadeTime",
        "ui_textScrollPauseEnd",
        "ui_textScrollPauseStart",
        "ui_textScrollSpeed",
        "uiscript_debug",
        "useonlinestats",
        "userGroup_active",
        "userGroup_cool_off_time",
        "userGroup_coop_delay",
        "userGroup_max_retry_time",
        "userGroup_refresh_time_secs",
        "userGroup_retry_step",
        "userGroup_RetryTime",
        "useStatsGroups",
        "useTagFlashSilenced",
        "using_mlg",
        "veh_aiOverSteerScale",
        "veh_boneControllerLodDist",
        "veh_drawTrack",
        "vehAudio_inAirPitchDownLerp",
        "vehAudio_inAirPitchUpLerp",
        "vehAudio_spawnVolumeTime",
        "vehBoatRockingScale",
        "vehCam_angles",
        "vehCam_angles3P",
        "vehCam_freeLook",
        "vehCam_mode",
        "vehCam_offset",
        "vehCam_offset3P",
        "vehCam_pitchClamp",
        "vehCam_pitchClamp3P",
        "vehCam_pitchTurnRate",
        "vehCam_pitchTurnRate3P",
        "vehCam_radius",
        "vehCam_radius3P",
        "vehCam_speedInfluence",
        "vehCam_speedInfluence3P",
        "vehCam_yawClamp",
        "vehCam_yawClamp3P",
        "vehCam_yawTurnRate",
        "vehCam_yawTurnRate3P",
        "vehCam_zOffsetMode",
        "vehCam_zOffsetMode3P",
        "vehHelicopterBoundsRadius",
        "vehHelicopterControlsAltitude",
        "vehHelicopterControlSystem",
        "vehHelicopterDecelerationFwd",
        "vehHelicopterDecelerationSide",
        "vehHelicopterDecelerationUp",
        "vehHelicopterForwardDrag",
        "vehHelicopterFreeLookReleaseSpeed",
        "vehHelicopterHeadSwayDontSwayTheTurret",
        "vehHelicopterHoverSpeedThreshold",
        "vehHelicopterInvertUpDown",
        "vehHelicopterJitterJerkyness",
        "vehHelicopterLateralDrag",
        "vehHelicopterLookaheadTime",
        "vehHelicopterMaxAccel",
        "vehHelicopterMaxAccelVertical",
        "vehHelicopterMaxAltitude",
        "vehHelicopterMaxPitch",
        "vehHelicopterMaxRoll",
        "vehHelicopterMaxSpeed",
        "vehHelicopterMaxSpeedVertical",
        "vehHelicopterMaxYawAccel",
        "vehHelicopterMaxYawRate",
        "vehHelicopterMinAltitude",
        "vehHelicopterPitchLock",
        "vehHelicopterPitchOffset",
        "vehHelicopterPitchRate",
        "vehHelicopterPitchReturn",
        "vehHelicopterPitchThrust",
        "vehHelicopterRightStickDeadzone",
        "vehHelicopterRollRate",
        "vehHelicopterRollReturn",
        "vehHelicopterRollThrust",
        "vehHelicopterScaleMovement",
        "vehHelicopterSoftCollisions",
        "vehHelicopterStrafeDeadzone",
        "vehHelicopterTiltFromAcceleration",
        "vehHelicopterTiltFromControllerAxes",
        "vehHelicopterTiltFromDeceleration",
        "vehHelicopterTiltFromFwdAndYaw",
        "vehHelicopterTiltFromFwdAndYaw_VelAtMaxTilt",
        "vehHelicopterTiltFromLook",
        "vehHelicopterTiltFromLookRate",
        "vehHelicopterTiltFromVelocity",
        "vehHelicopterTiltMomentum",
        "vehHelicopterTiltSpeed",
        "vehHelicopterVerticalDrag",
        "vehHelicopterYawOnLeftStick",
        "vehHudDrawPipOnStickWhenFreelooking",
        "vehHudLineWidth",
        "vehHudReticleBouncingDiamondSize",
        "vehHudReticleBouncingRadius",
        "vehHudReticleBouncingSpeed",
        "vehHudReticlePipOnAStickCenterCircle",
        "vehHudReticlePipOnAStickCenterCircleBuffer",
        "vehHudReticlePipOnAStickMovingCircle",
        "vehHudReticlePipOnAStickMovingCircleBuffer",
        "vehHudTargetScreenEdgeClampBufferBottom",
        "vehHudTargetScreenEdgeClampBufferLeft",
        "vehHudTargetScreenEdgeClampBufferRight",
        "vehHudTargetScreenEdgeClampBufferTop",
        "vehHudTargetSize",
        "vehicle_debug_render_spline_plane",
        "vehSubmarineAllowInSolid",
        "vehSubmarineBodyRelRotation",
        "vehSubmarineControls",
        "vehSubmarineForwardDampening",
        "vehSubmarineFwdCollMaxAccel",
        "vehSubmarineFwdCollMaxAngAccel",
        "vehSubmarineFwdProbeTime",
        "vehSubmarineHorizControlGamma",
        "vehSubmarineInvertUpDown",
        "vehSubmarineLateralDampening",
        "vehSubmarineMaxDownPitch",
        "vehSubmarineMaxForwardAccel",
        "vehSubmarineMaxForwardPitchAccel",
        "vehSubmarineMaxForwardVel",
        "vehSubmarineMaxForwardYawAccel",
        "vehSubmarineMaxFwdVelRef",
        "vehSubmarineMaxLateralVel",
        "vehSubmarineMaxNegativeBuoyancy",
        "vehSubmarineMaxPositiveBuoyancy",
        "vehSubmarineMaxReverseAccel",
        "vehSubmarineMaxReversePitchAccel",
        "vehSubmarineMaxReverseVel",
        "vehSubmarineMaxReverseYawAccel",
        "vehSubmarineMaxRoll",
        "vehSubmarineMaxRollAccel",
        "vehSubmarineMaxStoppedPitchAccel",
        "vehSubmarineMaxStoppedYawAccel",
        "vehSubmarineMaxUpPitch",
        "vehSubmarineMinForwardVel",
        "vehSubmarineMinVelNoRestore",
        "vehSubmarinePitchDampening",
        "vehSubmarinePitchRestore",
        "vehSubmarineRollDampening",
        "vehSubmarineRollDrivenYaw",
        "vehSubmarineRollRestore",
        "vehSubmarineSideCollMaxAccel",
        "vehSubmarineSideCollMaxAngAccel",
        "vehSubmarineSideProbeMaxDist",
        "vehSubmarineSideProbeMinDist",
        "vehSubmarineStoppedVel",
        "vehSubmarineVertControlGamma",
        "vehSubmarineYawDampening",
        "vehUGVPitchTrack",
        "vehUGVRollTrack",
        "vehUGVWheelInfluence",
        "version",
        "vid_xpos",
        "vid_ypos",
        "viewangNow",
        "viewModelDebugNotetracks",
        "viewModelHacks",
        "viewposNow",
        "waypointDebugDraw",
        "waypointDistScaleRangeMax",
        "waypointDistScaleRangeMin",
        "waypointDistScaleSmallest",
        "waypointIconHeight",
        "waypointIconWidth",
        "waypointOffscreenCornerRadius",
        "waypointOffscreenDistanceThresholdAlpha",
        "waypointOffscreenPadBottom",
        "waypointOffscreenPadLeft",
        "waypointOffscreenPadRight",
        "waypointOffscreenPadTop",
        "waypointOffscreenPointerDistance",
        "waypointOffscreenPointerHeight",
        "waypointOffscreenPointerWidth",
        "waypointOffscreenRoundedCorners",
        "waypointOffscreenScaleLength",
        "waypointOffscreenScaleSmallest",
        "waypointPlayerOffsetCrouch",
        "waypointPlayerOffsetProne",
        "waypointPlayerOffsetStand",
        "waypointScreenCenterFadeAdsMin",
        "waypointScreenCenterFadeHipMin",
        "waypointScreenCenterFadeRadius",
        "waypointSplitscreenScale",
        "waypointTweakY",
        "weapon_drop_validate_time",
        "wideScreen",
        "xblive_hostingprivateparty",
        "xblive_loggedin",
        "xblive_privatematch",
        "xblive_privatematch_solo",
    };

	game::dvar_t* register_int(const std::string& name, int value, int min, int max, 
		game::DvarFlags flags)
	{
		dvar_list.insert(name);
		const auto hash = game::generateHashValue(name.data());
		return game::Dvar_RegisterInt(hash, "", value, min, max, flags);
	}

	game::dvar_t* register_bool(const std::string& name, bool value, 
		game::DvarFlags flags)
	{
		dvar_list.insert(name);
		const auto hash = game::generateHashValue(name.data());
		return game::Dvar_RegisterBool(hash, "", value, flags);
	}

	game::dvar_t* register_float(const std::string& name, float value, float min, 
		float max, game::DvarFlags flags)
	{
		dvar_list.insert(name);
		const auto hash = game::generateHashValue(name.data());
		return game::Dvar_RegisterFloat(hash, "", value, min, max, flags);
	}

	game::dvar_t* register_vec4(const std::string& name, float x, float y, float z, 
		float w, float min, float max, game::DvarFlags flags)
	{
		dvar_list.insert(name);
		const auto hash = game::generateHashValue(name.data());
		return game::Dvar_RegisterVec4(hash, "", x, y, z, w, min, max, flags);
	}
}
